#!/usr/bin/env ruby

###
## Copyright 2009 by Adron Systems LLC, Laporte, MN  56461.
## Permission is granted to copy, distribute and/or modify this document.
##
##   Purpose: Output monitor channel information to stdout or output file.
##
##  Location: Adron\Engine\Macros.Ruby
##  Filename: Channels.rb
##
##   Started: 2009/06/01
##   Updated:[2016/04/01]
###

# Load the Vx Extract interface library.
require 'ExtractLoad'


###
## Routine displayHelp :
###

def displayHelp
  system("cls")
  printf("Monitor channel information display utility.  (Extract release : %s)\n", ASE::EXTRACT_RELEASE) ;
  puts
  printf("  %s [InFileName] [OutFileName] \n", File.basename($0))
  puts
  print("Options:\n")
  print("  InFileName   File to read (input) is first name specified.\n")
  print("  OutFileName  Output file is second name specified.\n")
  print("               If name not specified, then output goes to stdout.\n")
  puts
  print("  Optional items shown in [].\n")
  print("  No parameters generates this help screen.\n")
  puts
  print(ASE::ADRON_COPYRIGHT)
end


###
## Routine displayHeader :
###

def displayHeader( rdr, fout )
  if (0 < (cOfChannels = rdr.numberOfChannels))
    fout.printf("%14s%3s", "Interval(min)", "")
    0.upto(cOfChannels-1) do |j|
      fout.printf("%14s ", rdr.nameOfChannel( j ))
    end
    fout.puts
  end
end


###
## Routine displayChannels :
##
##      Interval value displayed in minutes.
##      Monitor channel values follow.
###

def displayChannels( rdr, fout )
  if (0 < (cOfScans = rdr.numberOfScans)) && (0 < (cOfChannels = rdr.numberOfChannels))
    0.upto(cOfScans-1) do |i|
      fout.printf("%14.4f : ", rdr.intervalOfScan(i)/60.0)
      0.upto(cOfChannels-1) do |j|
        fout.printf("%14g ", rdr.extractChannel( j, i ))
      end
      fout.puts
    end
  end
end


###
## Entrance :	
###

# No arguments, then display help screen.
if (ARGV.empty?)
  displayHelp
  Process.exit
end

# Open a ASE::Reader object.
begin
  rdr = ASE::Reader.new( ARGV[0] )
rescue Exception
  raise "Unable to create ASE::Reader object."
end

# Second argument is optional output file name.
fout = (nil != ARGV[1]) ? File.open(ARGV[1], "w+") : $stdout

# Display column header and monitor channel values.
displayHeader( rdr, fout )
displayChannels( rdr, fout )
